package status

import (
	"net/http"

	"github.com/gin-gonic/gin"
	log "github.com/sirupsen/logrus"
	"gitlab.127-0-0-1.fr/vx3r/wg-gen-web/core"
)

// ApplyRoutes applies router to gin Router
func ApplyRoutes(r *gin.RouterGroup) {
	g := r.Group("/status")
	{
		g.GET("/interface", readInterfaceStatus)
		g.GET("/clients", readClientStatus)
	}
}

func readInterfaceStatus(c *gin.Context) {
	status, err := core.ReadInterfaceStatus()
	if err != nil {
		log.WithFields(log.Fields{
			"err": err,
		}).Error("failed to read interface status")
		c.AbortWithStatus(http.StatusInternalServerError)
		return
	}

	c.JSON(http.StatusOK, status)
}

func readClientStatus(c *gin.Context) {
	status, err := core.ReadClientStatus()
	if err != nil {
		log.WithFields(log.Fields{
			"err": err,
		}).Error("failed to read client status")
		c.AbortWithStatus(http.StatusInternalServerError)
		return
	}

	c.JSON(http.StatusOK, status)
}
